==> tutti-ui-swing-2.3.2-sources.jar: fr/ifremer/tutti/ui/swing/util/caracteristics/CaracteristicMapEditorTableModel.java <==
package fr.ifremer.tutti.ui.swing.util.caracteristics;

/*
 * #%L
 * Tutti :: UI
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.util.table.AbstractTuttiTableModel;
import fr.ifremer.tutti.ui.swing.util.table.ColumnIdentifier;
import org.jdesktop.swingx.table.TableColumnModelExt;

import static org.nuiton.i18n.I18n.n_;

/**
 * @author kmorin <kmorin@codelutin.com>
 * @since 1.4
 */
public class CaracteristicMapEditorTableModel extends AbstractTuttiTableModel<CaracteristicMapEditorRowModel> {

    private static final long serialVersionUID = 1L;

    public static final ColumnIdentifier<CaracteristicMapEditorRowModel> KEY = ColumnIdentifier.newId(
            CaracteristicMapEditorRowModel.PROPERTY_KEY,
            n_("tutti.caracteristicMapEditorTable.table.header.key"),
            n_("tutti.caracteristicMapEditorTable.table.header.key"));

    public static final ColumnIdentifier<CaracteristicMapEditorRowModel> VALUE = ColumnIdentifier.newId(
            CaracteristicMapEditorRowModel.PROPERTY_VALUE,
            n_("tutti.caracteristicMapEditorTable.table.header.value"),
            n_("tutti.caracteristicMapEditorTable.table.header.value"));

    public CaracteristicMapEditorTableModel(TableColumnModelExt columnModel) {
        super(columnModel, false, false);
        setNoneEditableCols(KEY);
    }

    @Override
    public CaracteristicMapEditorRowModel createNewRow() {
        CaracteristicMapEditorRowModel result = new CaracteristicMapEditorRowModel();
        return result;
    }
}

==> tutti-ui-swing-3.0-sources.jar: fr/ifremer/tutti/ui/swing/util/caracteristics/CaracteristicMapEditorTableModel.java <==
package fr.ifremer.tutti.ui.swing.util.caracteristics;

/*
 * #%L
 * Tutti :: UI
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.shared.application.swing.table.AbstractApplicationTableModel;
import fr.ifremer.shared.application.swing.table.ColumnIdentifier;
import org.jdesktop.swingx.table.TableColumnModelExt;

import static org.nuiton.i18n.I18n.n_;

/**
 * @author kmorin <kmorin@codelutin.com>
 * @since 1.4
 */
public class CaracteristicMapEditorTableModel extends AbstractApplicationTableModel<CaracteristicMapEditorRowModel> {

    private static final long serialVersionUID = 1L;

    public static final ColumnIdentifier<CaracteristicMapEditorRowModel> KEY = ColumnIdentifier.newId(
            CaracteristicMapEditorRowModel.PROPERTY_KEY,
            n_("tutti.caracteristicMapEditorTable.table.header.key"),
            n_("tutti.caracteristicMapEditorTable.table.header.key"));

    public static final ColumnIdentifier<CaracteristicMapEditorRowModel> VALUE = ColumnIdentifier.newId(
            CaracteristicMapEditorRowModel.PROPERTY_VALUE,
            n_("tutti.caracteristicMapEditorTable.table.header.value"),
            n_("tutti.caracteristicMapEditorTable.table.header.value"));

    public CaracteristicMapEditorTableModel(TableColumnModelExt columnModel) {
        super(columnModel, false, false);
        setNoneEditableCols(KEY);
    }

    @Override
    public CaracteristicMapEditorRowModel createNewRow() {
        CaracteristicMapEditorRowModel result = new CaracteristicMapEditorRowModel();
        return result;
    }
}
